Module sequoia_wot::store
source · Expand description
Structs
Manages a slice of
&Cert.Attempts to fetch certificates from a keyserver.
Manages a slice of bytes or a slice of
&RawCert.Manages a slice of
&CertSynopsis.Enums
The different ways that a backend may return a certificate.
Store specific error codes.Traits
Returns certificates from a backing store.
A workaround to create a
Box<dyn Store + Backend>.