CertLints

Struct CertLints 

pub struct CertLints<'a> { /* private fields */ }
What we know about a certificate, and any errors or lints.

Sometimes we only know its Key ID.

This is indirectly returned by Network::lint_path.

The lifetimes 'a and 'b have the same meaning as for Store: 'a is the lifetime of the object on the backend, 'b is the lifetime of the reference to the object, and the object ('a) must outlive the reference ('b).

Implementations

Source

impl<'a> CertLints<'a>

pub fn key_handle(&self) -> KeyHandle

Returns the certificate’s KeyHandle.

pub fn primary_userid(&self) -> Option<UserID>

Returns the certificate’s primary User ID, if known.

Note: this is best effort, and the User ID may not be valid under the policy.

pub fn cert(&self) -> Option<&CertSynopsis>

Returns the CertSynopsis, if it is available.

pub fn errors(&self) -> &[Error]

Returns any errors.

Errors are fatal in the sense that the path is not valid.

pub fn lints(&self) -> &[Error]

Returns any lints.

Lints are not fatal in the sense that the lint does not necessarily invalidate the path.