Struct sequoia_wot::Network
source · pub struct Network<S>where
S: Store,{ /* private fields */ }Expand description
A certification network.
Implementations
sourceimpl<'a> Network<CertSlice<'a>>
impl<'a> Network<CertSlice<'a>>
sourcepub fn from_certs<T, P>(certs: &'a [Cert], policy: &'a P, t: T) -> Result<Self>where
T: Into<Option<SystemTime>>,
P: Policy,
pub fn from_certs<T, P>(certs: &'a [Cert], policy: &'a P, t: T) -> Result<Self>where
T: Into<Option<SystemTime>>,
P: Policy,
Builds a web of trust network from a set of certificates.
If a certificate is invalid according to the policy, the certificate is silently ignored.
sourceimpl<'a> Network<SynopsisSlice<'a>>
impl<'a> Network<SynopsisSlice<'a>>
sourcepub fn from_synopses(
certs: &'a [CertSynopsis],
certifications: &'a [Certification],
t: SystemTime
) -> Result<Self>
pub fn from_synopses(
certs: &'a [CertSynopsis],
certifications: &'a [Certification],
t: SystemTime
) -> Result<Self>
Builds a web of trust network from a set of certificates.
If a certificate is invalid according to the policy, the certificate is silently ignored.
sourceimpl<'a> Network<RawCerts<'a>>
impl<'a> Network<RawCerts<'a>>
sourcepub fn from_bytes<T>(
certs: &'a [u8],
policy: &'a dyn Policy,
t: T
) -> Result<Self>where
T: Into<Option<SystemTime>>,
pub fn from_bytes<T>(
certs: &'a [u8],
policy: &'a dyn Policy,
t: T
) -> Result<Self>where
T: Into<Option<SystemTime>>,
Builds a web of trust network from a keyring.
If a certificate is invalid according to the policy, the certificate is silently ignored.
sourcepub fn from_raw_certs<T>(
certs: &'a [RawCert<'a>],
policy: &'a dyn Policy,
t: T
) -> Result<Self>where
T: Into<Option<SystemTime>>,
pub fn from_raw_certs<T>(
certs: &'a [RawCert<'a>],
policy: &'a dyn Policy,
t: T
) -> Result<Self>where
T: Into<Option<SystemTime>>,
Builds a web of trust network from a set of raw certificates.
If a certificate is invalid according to the policy, the certificate is silently ignored.