PathLints

Struct PathLints 

pub struct PathLints<'a> { /* private fields */ }
A linted path.

This is returned by Network::lint_path.

The lifetimes 'a and 'b have the same meaning as for Store: 'a is the lifetime of the object on the backend, 'b is the lifetime of the reference to the object, and the object ('a) must outlive the reference ('b).

Implementations

Source

impl<'a> PathLints<'a>

pub fn certification_network(&self) -> bool

Returns whether the path is in a certification network.

In a certification network, depth constraints and regular expressions are ignored.

pub fn root(&self) -> &CertLints<'a>

Returns the path’s root.

pub fn target(&self) -> &CertLints<'a>

Returns the last node in the path.

pub fn certs(&self) -> impl Iterator<Item = &CertLints<'a>>

Returns an iterator over the certificates.

pub fn len(&self) -> usize

Returns the number of nodes (certificates) in the path.

pub fn certifications(&self) -> impl Iterator<Item = &CertificationLints>

Returns an iterator over the certifications.

pub fn amount(&self) -> usize

Returns the amount that the target is trusted.

120 usually means fully trusted. This function checks that there are no errors, that each certification’s depth parameter is sufficient for the rest of the path, and that the regular expression constraints are respected.

pub fn to_path(self) -> Result<Path>

Converts the PathLints into a Path.

This fails if the path is invalid. Note: the path is still considered valid even if it doesn’t have the required trust amount as passed to Network::lint_path.

There may be multiple reasons why a path is invalid. This function tries to return the first (when checking from the root towards the target) reason why it is not valid.