pub struct CertLints<'a> { /* private fields */ }Expand description
What we know about a certificate, and any errors or lints.
Sometimes we only know its Key ID.
This is indirectly returned by Network::lint_path.
The lifetimes 'a and 'b have the same meaning as for
Store: 'a is the lifetime of the object on the backend, 'b
is the lifetime of the reference to the object, and the object
('a) must outlive the reference ('b).
Implementations
Sourceimpl<'a> CertLints<'a>
impl<'a> CertLints<'a>
Sourcepub fn key_handle(&self) -> KeyHandle
pub fn key_handle(&self) -> KeyHandle
Returns the certificate’s KeyHandle.
Sourcepub fn primary_userid(&self) -> Option<UserID>
pub fn primary_userid(&self) -> Option<UserID>
Returns the certificate’s primary User ID, if known.
Note: this is best effort, and the User ID may not be valid under the policy.
Sourcepub fn cert(&self) -> Option<&CertSynopsis>
pub fn cert(&self) -> Option<&CertSynopsis>
Returns the CertSynopsis, if it is available.